# Django Watchlist

A stupidly simple system to allow users to watch/bookmark/favorite content.

Keeps track of which users like what.

Stores to session if user is not authenticated.

### Installation

`pip install django-watchlist`
